@@ -5,7 +5,7 @@
 #'
 #' The response (LHS of `formula`) can be one of the following:
 #' \tabular{ll}{
-#'   \code{n}, \code{count}, \code{N}, \code{abundance} \tab count in each segment\cr
+#'   \code{n}, \code{count}, \code{N} \tab count in each segment\cr
 #'   \code{Nhat}, \code{abundance.est} \tab estimated abundance per segment, estimation is via a Horvitz-Thompson estimator. This should be used when there are covariates in the detection function.\cr
 #'   \code{presence} \tab interpret the data as presence/absence (remember to change the \code{family} argument to \code{binomial()})\cr
 #'   \code{D}, \code{density}, \code{Dhat}, \code{density.est} \tab density per segment\cr
@@ -36,7 +36,7 @@
 #' @param observation.data observation data, see \code{\link{dsm-data}}.
 #' @param engine which fitting engine should be used for the DSM (\code{\link{glm}}/\code{\link{gam}}/\code{\link{gamm}}/\code{\link{bam}}).
 #' @param convert.units conversion factor to multiply the area of the segments by. See 'Units' below.
-#' @param family response distribution (popular choices include \code{\link{quasipoisson}}, \code{\link{Tweedie}} and \code{\link{negbin}}). Defaults to \code{quasipossion}.
+#' @param family response distribution (popular choices include \code{\link{quasipoisson}}, \code{\link{Tweedie}}/\code{\link{tw}} and \code{\link{negbin}}/\code{\link{nb}}). Defaults to \code{quasipossion}.
 #' @param group if \code{TRUE} the abundance of groups will be calculated rather than the abundance of individuals. Setting this option to \code{TRUE} is equivalent to setting the size of each group to be 1.
 #' @param control the usual \code{control} argument for a \code{gam}; \code{keepData} must be \code{TRUE} for variance estimation to work (though this option cannot be set for GLMs or GAMMs.
 #' @param availability an availability bias used to scale the counts/estimated  counts by. If we have \code{N} animals in a segment, then \code{N/availability} will be entered into the model. Uncertainty in the availability is not handled at present.
@@ -60,21 +60,20 @@
 #' @importFrom utils packageVersion
 #'
 #' @examples
+#' \dontrun{
 #' library(Distance)
 #' library(dsm)
 #'
 #' # load the Gulf of Mexico dolphin data (see ?mexdolphins)
 #' data(mexdolphins)
-#' attach(mexdolphins)
 #'
-#' \dontrun{
 #' # fit a detection function and look at the summary
 #' hr.model <- ds(distdata, max(distdata$distance),
 #'                key = "hr", adjustment = NULL)
 #' summary(hr.model)
 #'
-#' # fit a simple smooth of x and y
-#' mod1 <- dsm(N~s(x,y), hr.model, segdata, obsdata)
+#' # fit a simple smooth of x and y to counts
+#' mod1 <- dsm(count~s(x,y), hr.model, segdata, obsdata)
 #' summary(mod1)
 #'
 #' # predict over a grid
@@ -86,8 +85,6 @@
 #' # plot the smooth
 #' plot(mod1)
 #'}
-#' # detach the data
-#' detach("mexdolphins")
 dsm <- function(formula, ddf.obj, segment.data, observation.data,
                 engine="gam", convert.units=1,
                 family=quasipoisson(link="log"), group=FALSE, gamma=1.4,
@@ -108,7 +105,7 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
   ## check the formula
   response <- as.character(formula)[2]
   possible.responses <- c("D", "density", "Dhat", "density.est",
-                          "N", "abundance", "count", "n",
+                          "N", "count", "n",
                           "Nhat", "abundance.est",
                           "presence")
   if(!(response %in% possible.responses)){
@@ -150,7 +147,7 @@ dsm <- function(formula, ddf.obj, segment.data, observation.data,
   }
 
   # if we're using a gamm engine, warn if using an old version of mgcv
-  if(engine == "gamm" && dsm_env$old_version){
+  if(engine == "gamm" && dsm_env$old_mgcv){
       message("You are using mgcv version < 1.7-24, please update to at least 1.7-24 to avoid fitting problems.")
   }
 
