@@ -6,11 +6,12 @@
 #' See: http://romainfrancois.blog.free.fr/index.php?post/2009/05/20/Disable-specific-warnings
 #'
 #' @param w a warning
-#' @return not a warning if the warning was "matrix not positive definite"
+#' @return not a warning if the warning was "matrix not positive definite" or "the matrix is either rank-deficient or indefinite"
 #'
 #' @author David L. Miller
 matrixnotposdef.handler <- function(w){
-  if(any(grepl("matrix not positive definite",w))){
+  if(any(grepl("matrix not positive definite",w)) | 
+     any(grepl("the matrix is either rank-deficient or indefinite",w))){
     invokeRestart("muffleWarning")
   }
 }
